@@ -12,13 +12,13 @@ html_theme_options = {
     'base_url': 'http://bashtage.github.io/sphinx-material/',
     'repo_url': 'https://github.com/percona/percona-toolkit',
     'repo_name': 'percona/percona-toolkit',
-    'color_accent': 'grey',
-    'color_primary': 'orange',
+    'color_accent': 'cyan',
+    'color_primary': 'blue-grey',
     'globaltoc_collapse': True,
     'version_dropdown': True
 }
 html_logo = '../_static/percona-logo.svg'
-html_favicon = '../_static/percona_favicon.ico'
+html_favicon = '../_static/percona-favicon.ico'
 pygments_style = 'emacs'
 gitstamp_fmt = "%b %d, %Y"
 # Specify the text pattern that won't be copied with the code block contents
