@@ -55,10 +55,11 @@ const (
 
 //nolint:gochecknoglobals
 var (
-	Build     string = "2020-04-23"
-	GoVersion string = "1.14.1"
-	Version   string = "3.5.1"
-	Commit    string
+	// We do not set anything here, these variables are defined by the Makefile
+	Build     string //nolint
+	GoVersion string //nolint
+	Version   string //nolint
+	Commit    string //nolint
 
 	defaultConnectionTimeout = 3 * time.Second
 	directConnection         = true
